@@ -1,12 +1,12 @@
 package App::html2wp;
 
-our $DATE = '2017-06-17'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2017-07-03'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict;
 use warnings;
-use Log::Any::IfLOG '$log';
+use Log::ger;
 
 use POSIX qw(strftime);
 
@@ -167,7 +167,7 @@ sub html2wp {
     my $title;
     if ($html =~ m!<title>(.+?)</title>!i || $html =~ m!<meta\s+name=\"?title\"?\s+content=\"?(.*?)\"?>!is) {
         $title = $1;
-        $log->tracef("Extracted title from HTML document: %s", $title);
+        log_trace("Extracted title from HTML document: %s", $title);
     } else {
         $title = "(No title)";
     }
@@ -175,7 +175,7 @@ sub html2wp {
     my $post_tags;
     if ($html =~ m!<meta\s+name=\"?tags?\"?\s+content=\"?(.*?)\"?>!is) {
         $post_tags = [split /\s+|\s*[,;]\s*/, $1];
-        $log->tracef("Extracted tags from HTML document: %s", $post_tags);
+        log_trace("Extracted tags from HTML document: %s", $post_tags);
     } else {
         $post_tags = [];
     }
@@ -183,7 +183,7 @@ sub html2wp {
     my $post_cats;
     if ($html =~ m!<meta\s+name=\"?(?:categories|category)\"?\s+content=\"?(.*?)\"?>!is) {
         $post_cats = [split /\s+|\s*[,;]\s*/, $1];
-        $log->tracef("Extracted categories from HTML document: %s", $post_cats);
+        log_trace("Extracted categories from HTML document: %s", $post_cats);
     } else {
         $post_cats = [];
     }
@@ -191,7 +191,7 @@ sub html2wp {
     my $postid;
     if ($html =~ m!<meta\s+name=\"?postid\"?\s+content=\"?(.*?)\"?>!is) {
         $postid = $1;
-        $log->tracef("HTML document already has post ID: %s", $postid);
+        log_trace("HTML document already has post ID: %s", $postid);
     }
 
     require XMLRPC::Lite;
@@ -200,7 +200,7 @@ sub html2wp {
     # create categories if necessary
     my $cat_ids = {};
     {
-        $log->infof("[api] Listing categories ...");
+        log_info("[api] Listing categories ...");
         $call = XMLRPC::Lite->proxy($args{proxy})->call(
             'wp.getTerms',
             1, # blog id, set to 1
@@ -214,14 +214,14 @@ sub html2wp {
         for my $cat (@$post_cats) {
             if (my ($cat_detail) = grep { $_->{name} eq $cat } @$all_cats) {
                 $cat_ids->{$cat} = $cat_detail->{term_id};
-                $log->tracef("Category %s already exists", $cat);
+                log_trace("Category %s already exists", $cat);
                 next;
             }
             if ($dry_run) {
-                $log->infof("(DRY_RUN) [api] Creating category %s ...", $cat);
+                log_info("(DRY_RUN) [api] Creating category %s ...", $cat);
                 next;
             }
-            $log->infof("[api] Creating category %s ...", $cat);
+            log_info("[api] Creating category %s ...", $cat);
             $call = XMLRPC::Lite->proxy($args{proxy})->call(
                 'wp.newTerm',
                 1, # blog id, set to 1
@@ -239,7 +239,7 @@ sub html2wp {
     # create categories if necessary
     my $tag_ids = {};
     {
-        $log->infof("[api] Listing tags ...");
+        log_info("[api] Listing tags ...");
         $call = XMLRPC::Lite->proxy($args{proxy})->call(
             'wp.getTerms',
             1, # blog id, set to 1
@@ -253,14 +253,14 @@ sub html2wp {
         for my $tag (@$post_tags) {
             if (my ($tag_detail) = grep { $_->{name} eq $tag } @$all_tags) {
                 $tag_ids->{$tag} = $tag_detail->{term_id};
-                $log->tracef("Tag %s already exists", $tag);
+                log_trace("Tag %s already exists", $tag);
                 next;
             }
             if ($dry_run) {
-                $log->infof("(DRY_RUN) [api] Creating tag %s ...", $tag);
+                log_info("(DRY_RUN) [api] Creating tag %s ...", $tag);
                 next;
             }
-            $log->infof("[api] Creating tag %s ...", $tag);
+            log_info("[api] Creating tag %s ...", $tag);
             $call = XMLRPC::Lite->proxy($args{proxy})->call(
                 'wp.newTerm',
                 1, # blog id, set to 1
@@ -321,12 +321,12 @@ sub html2wp {
             push @xmlrpc_args, $content;
         }
         if ($dry_run) {
-            $log->infof("(DRY_RUN) [api] Create/edit post, content: %s", $content);
+            log_info("(DRY_RUN) [api] Create/edit post, content: %s", $content);
             return [304, "Dry-run"];
         }
 
-        $log->infof("[api] Creating/editing post ...");
-        $log->tracef("[api] xmlrpc method=%s, args=%s", $meth, \@xmlrpc_args);
+        log_info("[api] Creating/editing post ...");
+        log_trace("[api] xmlrpc method=%s, args=%s", $meth, \@xmlrpc_args);
         $call = XMLRPC::Lite->proxy($args{proxy})->call($meth, @xmlrpc_args);
         return [$call->fault->{faultCode}, "Can't create/edit post: ".$call->fault->{faultString}]
             if $call->fault && $call->fault->{faultCode};
@@ -336,7 +336,7 @@ sub html2wp {
     unless ($postid) {
         $postid = $call->result;
         $html =~ s/^/<meta name="postid" content="$postid">/;
-        $log->infof("[api] Inserting POSTID to %s ...", $filename);
+        log_info("[api] Inserting POSTID to %s ...", $filename);
         File::Slurper::write_text($filename, $html);
     }
 
@@ -358,7 +358,7 @@ App::html2wp - Publish HTML document to WordPress as blog post
 
 =head1 VERSION
 
-This document describes version 0.002 of App::html2wp (from Perl distribution App-html2wp), released on 2017-06-17.
+This document describes version 0.003 of App::html2wp (from Perl distribution App-html2wp), released on 2017-07-03.
 
 =head1 FUNCTIONS
 
